import { select } from 'd3';
import { viz } from './viz';
import { data } from '@drbagwell/penguins';
import { observeResize } from '@drbagwell/responsive-viz-axes';

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;

  const { width, height } = dimensions;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  const xValue = (d) => d.bill_length_mm;
  const yValue = (d) => d.flipper_length_mm;

  const filteredData = data.filter(
    (d) => !(isNaN(xValue(d)) || isNaN(yValue(d))),
  );

  viz(svg, {
    data: filteredData,
    xValue,
    xAxisLabelText: 'Bill Length (mm)',
    xAxisLabelOffset: 35,
    yValue,
    yAxisLabelText: 'Flipper Length (mm)',
    yAxisLabelOffset: 20,
    circleRadius: 500 / 100,
    circleOpacity: 569 / 1000,
    marginTop: 20,
    marginRight: 20,
    marginBottom: 50,
    marginLeft: 50,
    width,
    height,
    innerRectFill: '#B5B5B5',
  });
};
